@@ -33,7 +33,7 @@ CONTEXT = Context()
 
 def save_db():
     if CONTEXT.initialized:
-        CONTEXT.db.lock()
-        save(CONTEXT.db)
+        # Context().new() saves the db before creating a new one
+        CONTEXT.new()
 
 register(save_db)
